ring_promise
A minimal, ergonomic, and thread-friendly abstraction for submission/completion ring-based I/O. This crate provides a generic interface for working with submission and completion queues, allowing for flexible and efficient asynchronous I/O patterns.
Features
- Generic over submission and completion queue entry types
- Thread-safe sender abstraction
- Promise-based completion notification
- Minimal dependencies
Modules
- registry
- Registry for associating user data with completion senders.
- traits
- Traits for generic submission and completion ring-based I/O.
Structs
- PRing
Sender - A thread-safe sender for submitting entries to a ring and receiving completions as promises.
Enums
- Signal
- Represents a signal sent to the ring thread.